You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@subversion.apache.org by Evgeny Kotkov via dev <de...@subversion.apache.org> on 2026/09/24 11:21:00 UTC

Subversion 1.15.0 up for testing/signing

The 1.15.0 release artifacts are now available for testing/signing.
Please get the tarballs from
  https://dist.apache.org/repos/dist/dev/subversion
and add your signatures there.

Note: 1.15.0 tarballs should be functionally identical to 1.15.0-rc4 (they
are built from the same revision r1937767), with the only difference being
in the version number.

Thanks!

Re: Subversion 1.15.0 up for testing/signing

Posted by Branko Čibej <br...@apache.org>.
On 24. 9. 2026 13:21, Evgeny Kotkov via dev wrote:
> The 1.15.0 release artifacts are now available for testing/signing.
> Please get the tarballs from
>    https://dist.apache.org/repos/dist/dev/subversion
> and add your signatures there.
>
> Note: 1.15.0 tarballs should be functionally identical to 1.15.0-rc4 (they
> are built from the same revision r1937767), with the only difference being
> in the version number.
>
> Thanks!

+1

I Added my signature to the artefacts for 1.15.0. I checked that the 
contents of the archives were the same as for the previous release 
candidate, except for the expected differences in the version numbers 
and the POT generation timestamp.

-- Brane

Re: Subversion 1.15.0 up for testing/signing

Posted by Timofei Zhakov <ti...@chemodax.net>.
On Thu, Sep 24, 2026 at 1:22 PM Evgeny Kotkov via dev <
dev@subversion.apache.org> wrote:

> The 1.15.0 release artifacts are now available for testing/signing.
> Please get the tarballs from
>   https://dist.apache.org/repos/dist/dev/subversion
> and add your signatures there.
>
> Note: 1.15.0 tarballs should be functionally identical to 1.15.0-rc4 (they
> are built from the same revision r1937767), with the only difference being
> in the version number.
>
> Thanks!
>

+1 to release.

Checked:

- Contents of the tar balls are the same as -rc4 (besides version changes).
- Other signatures.

Committed my signature in r87883.

-- 
Timofei Zhakov

Re: Subversion 1.15.0 up for testing/signing

Posted by Ivan Zhakov <iv...@apache.org>.
On Thu, 24 Sept 2026 at 13:22, Evgeny Kotkov via dev <
dev@subversion.apache.org> wrote:

> The 1.15.0 release artifacts are now available for testing/signing.
> Please get the tarballs from
>   https://dist.apache.org/repos/dist/dev/subversion
> and add your signatures there.
>
> Note: 1.15.0 tarballs should be functionally identical to 1.15.0-rc4 (they
> are built from the same revision r1937767), with the only difference being
> in the version number.
>
>
Summary:

  +1 to release.

Tested:

 - Compared tarball with 1.15.0-rc4: the only difference are in
svn_version.h and subversion.pot.
 - Checked RM signatures


Signatures:

  (See the appropriate distribution files.)

-- 
Ivan Zhakov

Re: Subversion 1.15.0 up for testing/signing

Posted by Ivan Zhakov <iv...@apache.org>.
On Tue, 6 Oct 2026 at 17:50, Branko Čibej <br...@apache.org> wrote:

> On 6. 10. 2026 16:38, Ivan Zhakov wrote:
>
> On Tue, 6 Oct 2026 at 13:42, Branko Čibej <br...@apache.org> wrote:
>
>> On 6. 10. 2026 10:57, Ivan Zhakov wrote:
>>
>> On Mon, 5 Oct 2026 at 19:42, Branko Čibej <br...@apache.org> wrote:
>>
>>> On 24. 9. 2026 13:21, Evgeny Kotkov via dev wrote:
>>>
>>> The 1.15.0 release artifacts are now available for testing/signing.
>>> Please get the tarballs from
>>>   https://dist.apache.org/repos/dist/dev/subversion
>>> and add your signatures there.
>>>
>>> Note: 1.15.0 tarballs should be functionally identical to 1.15.0-rc4 (they
>>> are built from the same revision r1937767), with the only difference being
>>> in the version number.
>>>
>>> Thanks!
>>>
>>>
>>> I have an issue with the signatures for the .zip file:
>>>
>>> gpg: assuming signed data in 'dev/subversion-1.15.0.zip'
>>> ... skipped sig from Evgeny
>>> gpg: Signature made Fri Sep 25 12:54:09 2026 CEST
>>> gpg:                using RSA key D6678482E2ED5750E28B69292FB22D0D4ADC662A
>>> gpg: key 2FB22D0D4ADC662A: new key but contains no user ID - skipped
>>> gpg: Can't check signature: No public key
>>>
>>>
>>> I have the key in my keyring, but a public key without a user ID isn't
>>> valid. Could whoever owns this key add an ID and upload the updated key,
>>> please? Ivan, I think that's your new key, given what I see in the logs?
>>>
>>> It's my key.
>>
>> It's the same key that I used to sign Subversion 1.15.0-rc4.
>>
>> It's available on people.apache.org:
>> https://people.apache.org/keys/committer/ivan
>>
>> And PGP keyservers:
>>
>> https://keyserver.ubuntu.com/pks/lookup?search=D667+8482+E2ED+5750+E28B++6929+2FB2+2D0D+4ADC+662A&fingerprint=on&op=index
>>
>> https://keys.openpgp.org/vks/v1/by-fingerprint/D6678482E2ED5750E28B69292FB22D0D4ADC662A
>>
>> I also see it in the subversion-1.15.0.KEYS file.
>> [[[
>> ASF ID: ivan
>> LDAP PGP key: D667 8482 E2ED 5750 E28B  6929 2FB2 2D0D 4ADC 662A
>>
>> pub   rsa4096/2FB22D0D4ADC662A 2026-07-14 [SC]
>>       Key fingerprint = D667 8482 E2ED 5750 E28B  6929 2FB2 2D0D 4ADC 662A
>> uid                 [ unknown] Ivan Zhakov (CODE SIGNING KEY) <
>> ivan@apache.org>
>> sub   rsa4096/C62470648595D168 2026-07-14 [E]
>>       Key fingerprint = 9F3F 4DF5 6E1A EF95 73AB  F318 C624 7064 8595 D168
>> ....
>> ]]]
>>
>> May be I am missing something?
>>
>>
>> Or maybe I am. I didn't see this key in my rc4 tests, because I did the
>> signature check before you signed. Could it be gpg somehow got an
>> incomplete copy of it? That would be a huge bug, but I guess it's possible.
>> Let me check ...
>>
>>
>> ... so it turns out that your key did not propagate correctly to
>> keys.openpgp.org which I use by default, this is what I get:
>>
>> $ gpg --keyserver hkps://keys.openpgp.org --recv-keys 2FB22D0D4ADC662A
>> gpg: key 2FB22D0D4ADC662A: new key but contains no user ID - skipped
>> gpg: Total number processed: 1
>> gpg:           w/o user IDs: 1
>>
>>
>> Well, it's strange because the key is on keys.openpgp.org:
>
> https://keys.openpgp.org/vks/v1/by-fingerprint/D6678482E2ED5750E28B69292FB22D0D4ADC662A
>
>
>
> Yes, the key file is there, but it's incomplete. I downloaded it and
> checked the contents and there's no UID.
>
> $ gpg -v D6678482E2ED5750E28B69292FB22D0D4ADC662A.asc
> gpg: enabled compatibility flags:
> gpg: WARNING: no command supplied.  Trying to guess what you mean ...
> gpg: armor header: Comment: D667 8482 E2ED 5750 E28B  6929 2FB2 2D0D 4ADC 662A
> pub   rsa4096 2026-07-14 [SCEA]
>       D6678482E2ED5750E28B69292FB22D0D4ADC662A
> sub   rsa4096 2026-07-14 [E]
> sig        2FB22D0D4ADC662A 2026-07-14   [keybind]
>
>
> Only the pub, sub and sig fields are there, the uid field is missing. That
> field is present in the key that's available on keyserver.ubuntu.com.
>
>
It turns out that keys.openpgp.org server doesn't publish UID key
information without explicit confirmation via email. I have manually
uploaded key via website and confirmed my email.

Now keys.openpgp.org has UID information:
[[[
$ gpg -v D6678482E2ED5750E28B69292FB22D0D4ADC662A.asc
gpg: enabled compatibility flags:
gpg: WARNING: no command supplied.  Trying to guess what you mean ...
gpg: armor header: Comment: D667 8482 E2ED 5750 E28B  6929 2FB2 2D0D 4ADC
662A
gpg: armor header: Comment: Ivan Zhakov (CODE SIGNING KEY) <iv...@apache.org>
pub   rsa4096 2026-07-14 [SC]
      D6678482E2ED5750E28B69292FB22D0D4ADC662A
uid           Ivan Zhakov (CODE SIGNING KEY) <iv...@apache.org>
sig        2FB22D0D4ADC662A 2026-07-14   [selfsig]
sub   rsa4096 2026-07-14 [E]
sig        2FB22D0D4ADC662A 2026-07-14   [keybind]
]]]

-- 
Ivan Zhakov

Re: Subversion 1.15.0 up for testing/signing

Posted by Branko Čibej <br...@apache.org>.
On 6. 10. 2026 16:38, Ivan Zhakov wrote:
> On Tue, 6 Oct 2026 at 13:42, Branko Čibej <br...@apache.org> wrote:
>
>     On 6. 10. 2026 10:57, Ivan Zhakov wrote:
>>     On Mon, 5 Oct 2026 at 19:42, Branko Čibej <br...@apache.org> wrote:
>>
>>         On 24. 9. 2026 13:21, Evgeny Kotkov via dev wrote:
>>>         The 1.15.0 release artifacts are now available for testing/signing.
>>>         Please get the tarballs from
>>>            https://dist.apache.org/repos/dist/dev/subversion
>>>         and add your signatures there.
>>>
>>>         Note: 1.15.0 tarballs should be functionally identical to 1.15.0-rc4 (they
>>>         are built from the same revision r1937767), with the only difference being
>>>         in the version number.
>>>
>>>         Thanks!
>>
>>         I have an issue with the signatures for the .zip file:
>>
>>         gpg: assuming signed data in 'dev/subversion-1.15.0.zip'
>>         ... skipped sig from Evgeny
>>         gpg: Signature made Fri Sep 25 12:54:09 2026 CEST
>>         gpg:                using RSA key D6678482E2ED5750E28B69292FB22D0D4ADC662A
>>         gpg: key 2FB22D0D4ADC662A: new key but contains no user ID - skipped
>>         gpg: Can't check signature: No public key
>>
>>
>>         I have the key in my keyring, but a public key without a user
>>         ID isn't valid. Could whoever owns this key add an ID and
>>         upload the updated key, please? Ivan, I think that's your new
>>         key, given what I see in the logs?
>>
>>     It's my key.
>>     It's the same key that I used to sign Subversion 1.15.0-rc4.
>>
>>     It's available on people.apache.org <http://people.apache.org>:
>>     https://people.apache.org/keys/committer/ivan
>>
>>     And PGP keyservers:
>>     https://keyserver.ubuntu.com/pks/lookup?search=D667+8482+E2ED+5750+E28B++6929+2FB2+2D0D+4ADC+662A&fingerprint=on&op=index
>>     <https://keyserver.ubuntu.com/pks/lookup?search=D667+8482+E2ED+5750+E28B++6929+2FB2+2D0D+4ADC+662A&fingerprint=on&op=index>
>>     https://keys.openpgp.org/vks/v1/by-fingerprint/D6678482E2ED5750E28B69292FB22D0D4ADC662A
>>
>>     I also see it in the subversion-1.15.0.KEYS file.
>>     [[[
>>     ASF ID: ivan
>>     LDAP PGP key: D667 8482 E2ED 5750 E28B  6929 2FB2 2D0D 4ADC 662A
>>
>>     pub   rsa4096/2FB22D0D4ADC662A 2026-07-14 [SC]
>>           Key fingerprint = D667 8482 E2ED 5750 E28B  6929 2FB2 2D0D
>>     4ADC 662A
>>     uid                 [ unknown] Ivan Zhakov (CODE SIGNING KEY)
>>     <iv...@apache.org>
>>     sub   rsa4096/C62470648595D168 2026-07-14 [E]
>>           Key fingerprint = 9F3F 4DF5 6E1A EF95 73AB  F318 C624 7064
>>     8595 D168
>>     ....
>>     ]]]
>>
>>     May be I am missing something?
>
>     Or maybe I am. I didn't see this key in my rc4 tests, because I
>     did the signature check before you signed. Could it be gpg somehow
>     got an incomplete copy of it? That would be a huge bug, but I
>     guess it's possible. Let me check ...
>
>
>     ... so it turns out that your key did not propagate correctly to
>     keys.openpgp.org <http://keys.openpgp.org> which I use by default,
>     this is what I get:
>
>     $ gpg --keyserver hkps://keys.openpgp.org <http://keys.openpgp.org> --recv-keys 2FB22D0D4ADC662A
>     gpg: key 2FB22D0D4ADC662A: new key but contains no user ID - skipped
>     gpg: Total number processed: 1
>     gpg:           w/o user IDs: 1
>
>
> Well, it's strange because the key is on keys.openpgp.org 
> <http://keys.openpgp.org>:
> https://keys.openpgp.org/vks/v1/by-fingerprint/D6678482E2ED5750E28B69292FB22D0D4ADC662A 
>
>


Yes, the key file is there, but it's incomplete. I downloaded it and 
checked the contents and there's no UID.

$ gpg -v D6678482E2ED5750E28B69292FB22D0D4ADC662A.asc
gpg: enabled compatibility flags:
gpg: WARNING: no command supplied.  Trying to guess what you mean ...
gpg: armor header: Comment: D667 8482 E2ED 5750 E28B  6929 2FB2 2D0D 4ADC 662A
pub   rsa4096 2026-07-14 [SCEA]
       D6678482E2ED5750E28B69292FB22D0D4ADC662A
sub   rsa4096 2026-07-14 [E]
sig        2FB22D0D4ADC662A 2026-07-14   [keybind]


Only the pub, sub and sig fields are there, the uid field is missing. 
That field is present in the key that's available on keyserver.ubuntu.com.

-- Brane

Re: Subversion 1.15.0 up for testing/signing

Posted by Ivan Zhakov <iv...@apache.org>.
On Tue, 6 Oct 2026 at 13:42, Branko Čibej <br...@apache.org> wrote:

> On 6. 10. 2026 10:57, Ivan Zhakov wrote:
>
> On Mon, 5 Oct 2026 at 19:42, Branko Čibej <br...@apache.org> wrote:
>
>> On 24. 9. 2026 13:21, Evgeny Kotkov via dev wrote:
>>
>> The 1.15.0 release artifacts are now available for testing/signing.
>> Please get the tarballs from
>>   https://dist.apache.org/repos/dist/dev/subversion
>> and add your signatures there.
>>
>> Note: 1.15.0 tarballs should be functionally identical to 1.15.0-rc4 (they
>> are built from the same revision r1937767), with the only difference being
>> in the version number.
>>
>> Thanks!
>>
>>
>> I have an issue with the signatures for the .zip file:
>>
>> gpg: assuming signed data in 'dev/subversion-1.15.0.zip'
>> ... skipped sig from Evgeny
>> gpg: Signature made Fri Sep 25 12:54:09 2026 CEST
>> gpg:                using RSA key D6678482E2ED5750E28B69292FB22D0D4ADC662A
>> gpg: key 2FB22D0D4ADC662A: new key but contains no user ID - skipped
>> gpg: Can't check signature: No public key
>>
>>
>> I have the key in my keyring, but a public key without a user ID isn't
>> valid. Could whoever owns this key add an ID and upload the updated key,
>> please? Ivan, I think that's your new key, given what I see in the logs?
>>
>> It's my key.
>
> It's the same key that I used to sign Subversion 1.15.0-rc4.
>
> It's available on people.apache.org:
> https://people.apache.org/keys/committer/ivan
>
> And PGP keyservers:
>
> https://keyserver.ubuntu.com/pks/lookup?search=D667+8482+E2ED+5750+E28B++6929+2FB2+2D0D+4ADC+662A&fingerprint=on&op=index
>
> https://keys.openpgp.org/vks/v1/by-fingerprint/D6678482E2ED5750E28B69292FB22D0D4ADC662A
>
> I also see it in the subversion-1.15.0.KEYS file.
> [[[
> ASF ID: ivan
> LDAP PGP key: D667 8482 E2ED 5750 E28B  6929 2FB2 2D0D 4ADC 662A
>
> pub   rsa4096/2FB22D0D4ADC662A 2026-07-14 [SC]
>       Key fingerprint = D667 8482 E2ED 5750 E28B  6929 2FB2 2D0D 4ADC 662A
> uid                 [ unknown] Ivan Zhakov (CODE SIGNING KEY) <
> ivan@apache.org>
> sub   rsa4096/C62470648595D168 2026-07-14 [E]
>       Key fingerprint = 9F3F 4DF5 6E1A EF95 73AB  F318 C624 7064 8595 D168
> ....
> ]]]
>
> May be I am missing something?
>
>
> Or maybe I am. I didn't see this key in my rc4 tests, because I did the
> signature check before you signed. Could it be gpg somehow got an
> incomplete copy of it? That would be a huge bug, but I guess it's possible.
> Let me check ...
>
>
> ... so it turns out that your key did not propagate correctly to
> keys.openpgp.org which I use by default, this is what I get:
>
> $ gpg --keyserver hkps://keys.openpgp.org --recv-keys 2FB22D0D4ADC662A
> gpg: key 2FB22D0D4ADC662A: new key but contains no user ID - skipped
> gpg: Total number processed: 1
> gpg:           w/o user IDs: 1
>
>
> Well, it's strange because the key is on keys.openpgp.org:
https://keys.openpgp.org/vks/v1/by-fingerprint/D6678482E2ED5750E28B69292FB22D0D4ADC662A

-- 
Ivan Zhakov

Re: Subversion 1.15.0 up for testing/signing

Posted by Branko Čibej <br...@apache.org>.
On 6. 10. 2026 10:57, Ivan Zhakov wrote:
> On Mon, 5 Oct 2026 at 19:42, Branko Čibej <br...@apache.org> wrote:
>
>     On 24. 9. 2026 13:21, Evgeny Kotkov via dev wrote:
>>     The 1.15.0 release artifacts are now available for testing/signing.
>>     Please get the tarballs from
>>        https://dist.apache.org/repos/dist/dev/subversion
>>     and add your signatures there.
>>
>>     Note: 1.15.0 tarballs should be functionally identical to 1.15.0-rc4 (they
>>     are built from the same revision r1937767), with the only difference being
>>     in the version number.
>>
>>     Thanks!
>
>     I have an issue with the signatures for the .zip file:
>
>     gpg: assuming signed data in 'dev/subversion-1.15.0.zip'
>     ... skipped sig from Evgeny
>     gpg: Signature made Fri Sep 25 12:54:09 2026 CEST
>     gpg:                using RSA key D6678482E2ED5750E28B69292FB22D0D4ADC662A
>     gpg: key 2FB22D0D4ADC662A: new key but contains no user ID - skipped
>     gpg: Can't check signature: No public key
>
>
>     I have the key in my keyring, but a public key without a user ID
>     isn't valid. Could whoever owns this key add an ID and upload the
>     updated key, please? Ivan, I think that's your new key, given what
>     I see in the logs?
>
> It's my key.
> It's the same key that I used to sign Subversion 1.15.0-rc4.
>
> It's available on people.apache.org <http://people.apache.org>:
> https://people.apache.org/keys/committer/ivan
>
> And PGP keyservers:
> https://keyserver.ubuntu.com/pks/lookup?search=D667+8482+E2ED+5750+E28B++6929+2FB2+2D0D+4ADC+662A&fingerprint=on&op=index 
> <https://keyserver.ubuntu.com/pks/lookup?search=D667+8482+E2ED+5750+E28B++6929+2FB2+2D0D+4ADC+662A&fingerprint=on&op=index>
> https://keys.openpgp.org/vks/v1/by-fingerprint/D6678482E2ED5750E28B69292FB22D0D4ADC662A
>
> I also see it in the subversion-1.15.0.KEYS file.
> [[[
> ASF ID: ivan
> LDAP PGP key: D667 8482 E2ED 5750 E28B  6929 2FB2 2D0D 4ADC 662A
>
> pub   rsa4096/2FB22D0D4ADC662A 2026-07-14 [SC]
>       Key fingerprint = D667 8482 E2ED 5750 E28B  6929 2FB2 2D0D 4ADC 662A
> uid                 [ unknown] Ivan Zhakov (CODE SIGNING KEY) 
> <iv...@apache.org>
> sub   rsa4096/C62470648595D168 2026-07-14 [E]
>       Key fingerprint = 9F3F 4DF5 6E1A EF95 73AB  F318 C624 7064 8595 D168
> ....
> ]]]
>
> May be I am missing something?

Or maybe I am. I didn't see this key in my rc4 tests, because I did the 
signature check before you signed. Could it be gpg somehow got an 
incomplete copy of it? That would be a huge bug, but I guess it's 
possible. Let me check ...


... so it turns out that your key did not propagate correctly to 
keys.openpgp.org which I use by default, this is what I get:

$ gpg --keyserver hkps://keys.openpgp.org --recv-keys 2FB22D0D4ADC662A
gpg: key 2FB22D0D4ADC662A: new key but contains no user ID - skipped
gpg: Total number processed: 1
gpg:           w/o user IDs: 1


but I can retrieve it from keyserver.ubuntu.com:

$ gpg --keyserver hkps://keyserver.ubuntu.com --recv-keys 2FB22D0D4ADC662A
gpg: key 2FB22D0D4ADC662A: public key "Ivan Zhakov (CODE SIGNING KEY)<iv...@apache.org>" imported
gpg: Total number processed: 1
gpg:               imported: 1


I did not expect this at all. You should probably look into it.

-- Brane

Re: Subversion 1.15.0 up for testing/signing

Posted by Ivan Zhakov <iv...@apache.org>.
On Mon, 5 Oct 2026 at 19:42, Branko Čibej <br...@apache.org> wrote:

> On 24. 9. 2026 13:21, Evgeny Kotkov via dev wrote:
>
> The 1.15.0 release artifacts are now available for testing/signing.
> Please get the tarballs from
>   https://dist.apache.org/repos/dist/dev/subversion
> and add your signatures there.
>
> Note: 1.15.0 tarballs should be functionally identical to 1.15.0-rc4 (they
> are built from the same revision r1937767), with the only difference being
> in the version number.
>
> Thanks!
>
>
> I have an issue with the signatures for the .zip file:
>
> gpg: assuming signed data in 'dev/subversion-1.15.0.zip'
> ... skipped sig from Evgeny
> gpg: Signature made Fri Sep 25 12:54:09 2026 CEST
> gpg:                using RSA key D6678482E2ED5750E28B69292FB22D0D4ADC662A
> gpg: key 2FB22D0D4ADC662A: new key but contains no user ID - skipped
> gpg: Can't check signature: No public key
>
>
> I have the key in my keyring, but a public key without a user ID isn't
> valid. Could whoever owns this key add an ID and upload the updated key,
> please? Ivan, I think that's your new key, given what I see in the logs?
>
> It's my key.

It's the same key that I used to sign Subversion 1.15.0-rc4.

It's available on people.apache.org:
https://people.apache.org/keys/committer/ivan

And PGP keyservers:
https://keyserver.ubuntu.com/pks/lookup?search=D667+8482+E2ED+5750+E28B++6929+2FB2+2D0D+4ADC+662A&fingerprint=on&op=index
https://keys.openpgp.org/vks/v1/by-fingerprint/D6678482E2ED5750E28B69292FB22D0D4ADC662A

I also see it in the subversion-1.15.0.KEYS file.
[[[
ASF ID: ivan
LDAP PGP key: D667 8482 E2ED 5750 E28B  6929 2FB2 2D0D 4ADC 662A

pub   rsa4096/2FB22D0D4ADC662A 2026-07-14 [SC]
      Key fingerprint = D667 8482 E2ED 5750 E28B  6929 2FB2 2D0D 4ADC 662A
uid                 [ unknown] Ivan Zhakov (CODE SIGNING KEY) <
ivan@apache.org>
sub   rsa4096/C62470648595D168 2026-07-14 [E]
      Key fingerprint = 9F3F 4DF5 6E1A EF95 73AB  F318 C624 7064 8595 D168
....
]]]

May be I am missing something?

-- 
Ivan Zhakov

Re: Subversion 1.15.0 up for testing/signing

Posted by Branko Čibej <br...@apache.org>.
On 24. 9. 2026 13:21, Evgeny Kotkov via dev wrote:
> The 1.15.0 release artifacts are now available for testing/signing.
> Please get the tarballs from
>    https://dist.apache.org/repos/dist/dev/subversion
> and add your signatures there.
>
> Note: 1.15.0 tarballs should be functionally identical to 1.15.0-rc4 (they
> are built from the same revision r1937767), with the only difference being
> in the version number.
>
> Thanks!

I have an issue with the signatures for the .zip file:

gpg: assuming signed data in 'dev/subversion-1.15.0.zip'
... skipped sig from Evgeny
gpg: Signature made Fri Sep 25 12:54:09 2026 CEST
gpg:                using RSA key D6678482E2ED5750E28B69292FB22D0D4ADC662A
gpg: key 2FB22D0D4ADC662A: new key but contains no user ID - skipped
gpg: Can't check signature: No public key


I have the key in my keyring, but a public key without a user ID isn't 
valid. Could whoever owns this key add an ID and upload the updated key, 
please? Ivan, I think that's your new key, given what I see in the logs?

-- Brane

Re: Subversion 1.15.0 up for testing/signing

Posted by Evgeny Kotkov via dev <de...@subversion.apache.org>.
Evgeny Kotkov <ev...@axiorema.com> writes:

> The 1.15.0 release artifacts are now available for testing/signing.
> Please get the tarballs from
>   https://dist.apache.org/repos/dist/dev/subversion
> and add your signatures there.
>
> Note: 1.15.0 tarballs should be functionally identical to 1.15.0-rc4 (they
> are built from the same revision r1937767), with the only difference being
> in the version number.

Hi all,

A gentle ping: I believe we're one vote short of being able to release
this build.

If someone has time to verify the build and vote, that would be much
appreciated.


Thanks,
Evgeny Kotkov

Re: Subversion 1.15.0 up for testing/signing

Posted by Karl Fogel <kf...@red-bean.com>.
On 05 Oct 2026, Evgeny Kotkov via dev wrote:
>> The 1.15.0 release artifacts are now available for 
>> testing/signing.
>> Please get the tarballs from
>>   https://dist.apache.org/repos/dist/dev/subversion
>> and add your signatures there.
>
>We have all the necessary votes for this release.  I plan to 
>publish
>the 1.15.0 artifacts on Wednesday, October 7 and send the 
>announcement
>on Thursday, October 8.

This is so enjoyable to anticipate that I almost don't want you to 
make the release, so that I can go on enjoying anticipating it for 
longer!

Go go go,

-Karl

Re: Subversion 1.15.0 up for testing/signing

Posted by Evgeny Kotkov via dev <de...@subversion.apache.org>.
Evgeny Kotkov <ev...@axiorema.com> writes:

> The 1.15.0 release artifacts are now available for testing/signing.
> Please get the tarballs from
>   https://dist.apache.org/repos/dist/dev/subversion
> and add your signatures there.

We have all the necessary votes for this release.  I plan to publish
the 1.15.0 artifacts on Wednesday, October 7 and send the announcement
on Thursday, October 8.


Thanks,
Evgeny Kotkov

Re: Subversion 1.15.0 up for testing/signing

Posted by Nathan Hartman <ha...@gmail.com>.
On Thu, Sep 24, 2026 at 7:23 AM Evgeny Kotkov via dev
<de...@subversion.apache.org> wrote:
>
> The 1.15.0 release artifacts are now available for testing/signing.
> Please get the tarballs from
>   https://dist.apache.org/repos/dist/dev/subversion
> and add your signatures there.
>
> Note: 1.15.0 tarballs should be functionally identical to 1.15.0-rc4 (they
> are built from the same revision r1937767), with the only difference being
> in the version number.
>
> Thanks!

Summary:
+1 to release (Unix)

Checked:
* GPG signatures
* sha512 checksums
* Contents of subversion-1.15.0 are identical to subversion-1.15.0-rc4
  except expected differences:
  - Version numbers in generated files (svn_version.h, SWIG bindings'
    core.c)
  - Timestamp in generated file (subversion.pot)
* Contents of .tar.bz2 identical to contents of .tar.gz.
* Contents of .tar.bz2/.tar.gz identical to contents of .zip except for
  expected platform differences:
  - Generated SWIG bindings
  - Absence of unix build files

Platform: Ubuntu 26.04.1 LTS "resolute"

Dependencies:
APR 1.7.6 (compiled with 1.7.6)
APR-Util 1.6.3 (compiled with 1.6.3)
Expat 2.7.4 (compiled with 2.7.4)
SQLite 3.46.1 (compiled with 3.46.1)
Utf8proc 2.10.0 (compiled with 2.10.0)
ZLib 1.3.1 (compiled with 1.3.1)
LZ4 1.10.0 (compiled with 1.10.0)

Notes:
1. Did we intend to include .github directory in the release artifacts?
2. subversion.pot: Contains placeholder text in the file's header

Tested: [fsfs] x [ra_local | ra_svn]

Test results: All tests successful.

Signatures:

subversion-1.15.0.tar.bz2:
-----BEGIN PGP SIGNATURE-----

iQIzBAABCAAdFiEEP45GfLM2bjAT4RINWD8ArfmBw58FAmrDHmAACgkQWD8ArfmB
w582OhAAglFfHyz5xXLOLbxn4bQkUl2htrFr3gdYq7KRzPBRE62WjMfVDYzpU9PT
RNA5kbjEABeaOpF/P/nPfJuT3jvaTp5NwtOCFEiSsTaKk+iBM6Yg98MdylaAmOLl
J8exAQ0/oqn9qrREo8WFf9MDUcTCylw6sV6yZTbO/nAjepHS21KEvRt7tVyeTFEs
Sn9CzdiuoOr2jcLLNTPe/15xCvHHwhSXp9iUn1GDIztHbmsaJVw/YZcHwn8mzyvG
uxvN/dz4hls4f/Sdvjyle67wJt/9y0jJn0TGy6jJmesFHuGop8RgCssko4+vXk03
eA/yY+ibZHV/uuyKEdAaS5nG+AucWR6S0576/7+7G/Kdr3ywUBM8x3sGJlhm8pAs
owWEIxeB3LTJWYA7WuhVoC7+M4WbINjkha+yuvIArSRlAvOt35+vpkvobSVcIdoK
HSJ7aBrV4dx7G8sYIOwE3LcwvCjxX9wjKkBDKFj27up68FJgg5sRga5dGx6p/fu8
BqoB+imoUJiFgzjYvEB+bAp4EMhX93ns/j6tBflnOYjLCvSOV3uamZSOoGe/J6PI
BlzwLkBCkLKxYuwHHCH+kvZ2xTBi4KcvStdwMq660NoCHXIPvRPdGj6DDINWL+ue
8w9PJidIcaIDySQDZe6d/XwzQ2Li4LGSwhs4AbIyyiiVAvflToI=
=12g+
-----END PGP SIGNATURE-----

subversion-1.15.0.tar.gz:
-----BEGIN PGP SIGNATURE-----

iQIzBAABCAAdFiEEP45GfLM2bjAT4RINWD8ArfmBw58FAmrDHpwACgkQWD8ArfmB
w5/VIw/5AfjJlsU0n6YL8hzwLun175p9y1N1mNQMh/Th0H1nV7JPykpukJJ49NlB
nWdodmWkyUTBDU0fCAe9NzWeU0gNAzzK4LPt1YO1Aoy+TqVXVRKIkdUpLX3z4sVM
fxpPfH+3BopgsKAGiioO41LNDAqr3ARTu6J5rjUtTJNcgD21TI2O2XotXc8Mb+vx
G1yQ3//2AHbuCDPxuO9ecGutoYmDBA/dFQICwoFHp70atTXK6bauuoMOSHHSqBZJ
kjm05Xc5vW8zCOuVjCKfsypdfGa0FIOkqF2NKuZx+/MgenjPefWbd4dVpk9Amisa
MgPcT7eK5CMrJdzHjNA1dTLFkMpSzAldqcJ05WZJ8aySGVGfZ5zhLJH22NbatH/d
7t7rDaov31JtsBb09FPsgMV5bl07PGrzX/0Q9KgiAW6cYr/8wKSdt2MNQlaihUm3
kdRebKUULaCWPxSCEM474cUfs182jE6AgyWB8IKAr8hdCzsxkp5QvWz5xl8609YL
bYgY1lDWJuw/791PPeQc1yd3bC0BMQBNRceT29wZjvrSxSMpC1gNpv3pMP+tbjZq
/7femiR2IKIuofCFXXyapGvIwt6y9QPE1aJ4f/Q1/lOEgliPkypOuw/GDaOWvN20
fTIAtRciqYS0oP27MVDm6a0d4OqIY+gQ8Hl35uAOJCIQIZZGq0M=
=WsT4
-----END PGP SIGNATURE-----

Signatures committed in r88193 at
https://dist.apache.org/repos/dist/dev/subversion

A great big THANK YOU to our Release Manager and the entire Subversion
Development community for making this release possible!

Best regards,
Nathan